==> jc-1.4.0.tar.gz: java/security/spec/DSAPrivateKeySpec.h <==
// public class java.security.spec.DSAPrivateKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 61e0ec33066ad42 java_security_spec_DSAPrivateKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_DSAPrivateKeySpec_H_
#define _JC_java_security_spec_DSAPrivateKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$sub_refs	_jc_java_security_spec_DSAPrivateKeySpec$sub_refs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs	_jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$refs	_jc_java_security_spec_DSAPrivateKeySpec$refs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$nonrefs	_jc_java_security_spec_DSAPrivateKeySpec$nonrefs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$object	_jc_java_security_spec_DSAPrivateKeySpec$object;

typedef const struct _jc_java_security_spec_DSAPrivateKeySpec$vmethods	_jc_java_security_spec_DSAPrivateKeySpec$vmethods;
typedef const struct _jc_java_security_spec_DSAPrivateKeySpec$vtable	_jc_java_security_spec_DSAPrivateKeySpec$vtable;
typedef const struct _jc_java_security_spec_DSAPrivateKeySpec$vtype	_jc_java_security_spec_DSAPrivateKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_DSAPrivateKeySpec$method$_init$af886985c1050c26(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getQ$e08c53541a87120d(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getX$568a3b7b0d38db21(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
extern void _jc_java_security_spec_DSAPrivateKeySpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getQ$e08c53541a87120d;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getX$568a3b7b0d38db21;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_spec_DSAPrivateKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getQ$e08c53541a87120d)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getX$568a3b7b0d38db21)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *);
};

// Vtable
struct _jc_java_security_spec_DSAPrivateKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_DSAPrivateKeySpec$vmethods	java_security_spec_DSAPrivateKeySpec;
};

// Vtype
struct _jc_java_security_spec_DSAPrivateKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_DSAPrivateKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_DSAPrivateKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*x;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_java_security_spec_DSAPrivateKeySpec$refs {
    _jc_java_security_spec_DSAPrivateKeySpec$sub_refs	java_security_spec_DSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_DSAPrivateKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs	java_security_spec_DSAPrivateKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_DSAPrivateKeySpec$object {
	_jc_java_security_spec_DSAPrivateKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_DSAPrivateKeySpec$vtype	*vtype;
	_jc_java_security_spec_DSAPrivateKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_DSAPrivateKeySpec$vtype _jc_java_security_spec_DSAPrivateKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_DSAPrivateKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_DSAPrivateKeySpec$class_object;

#endif	/* _JC_java_security_spec_DSAPrivateKeySpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/DSAPrivateKeySpec.h <==
// public class java.security.spec.DSAPrivateKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 61e0ec33066ad42 java_security_spec_DSAPrivateKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_DSAPrivateKeySpec_H_
#define _JC_java_security_spec_DSAPrivateKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$sub_refs	_jc_java_security_spec_DSAPrivateKeySpec$sub_refs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs	_jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$refs	_jc_java_security_spec_DSAPrivateKeySpec$refs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$nonrefs	_jc_java_security_spec_DSAPrivateKeySpec$nonrefs;
typedef struct _jc_java_security_spec_DSAPrivateKeySpec$object	_jc_java_security_spec_DSAPrivateKeySpec$object;

typedef const struct _jc_java_security_spec_DSAPrivateKeySpec$vmethods	_jc_java_security_spec_DSAPrivateKeySpec$vmethods;
typedef const struct _jc_java_security_spec_DSAPrivateKeySpec$vtable	_jc_java_security_spec_DSAPrivateKeySpec$vtable;
typedef const struct _jc_java_security_spec_DSAPrivateKeySpec$vtype	_jc_java_security_spec_DSAPrivateKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_DSAPrivateKeySpec$method$_init$af886985c1050c26(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getQ$e08c53541a87120d(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPrivateKeySpec$method$getX$568a3b7b0d38db21(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_spec_DSAPrivateKeySpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getQ$e08c53541a87120d;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$getX$568a3b7b0d38db21;
extern _jc_method _jc_java_security_spec_DSAPrivateKeySpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_spec_DSAPrivateKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getQ$e08c53541a87120d)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getX$568a3b7b0d38db21)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_spec_DSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_DSAPrivateKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_DSAPrivateKeySpec$vmethods	java_security_spec_DSAPrivateKeySpec;
};

// Vtype
struct _jc_java_security_spec_DSAPrivateKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_DSAPrivateKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_DSAPrivateKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*x;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_java_security_spec_DSAPrivateKeySpec$refs {
    _jc_java_security_spec_DSAPrivateKeySpec$sub_refs	java_security_spec_DSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_DSAPrivateKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_DSAPrivateKeySpec$sub_nonrefs	java_security_spec_DSAPrivateKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_DSAPrivateKeySpec$object {
	_jc_java_security_spec_DSAPrivateKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_DSAPrivateKeySpec$vtype	*vtype;
	_jc_java_security_spec_DSAPrivateKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_DSAPrivateKeySpec$vtype _jc_java_security_spec_DSAPrivateKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_DSAPrivateKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_DSAPrivateKeySpec$class_object;

#endif	/* _JC_java_security_spec_DSAPrivateKeySpec_H_ */
